% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/btl.R
\name{plot_btl}
\alias{plot_btl}
\title{Plot Bradley-Terry-Luce object locations}
\usage{
plot_btl(fit, band = 2.5)
}
\arguments{
\item{fit}{An object from \code{\link{btl}}.}

\item{band}{Absolute fit-residual value beyond which an object is
highlighted.}
}
\value{
Called for its plotting side effect; invisibly \code{NULL}.
}
\description{
Caterpillar plot of the object locations with 95 per cent error bars,
misfitting objects highlighted, in the package's house style.
}
\examples{
set.seed(1)
beta <- c(A = -1, B = -0.3, C = 0.4, D = 0.9)
pairs <- t(combn(names(beta), 2))
d <- data.frame(a = rep(pairs[, 1], each = 30),
                b = rep(pairs[, 2], each = 30))
p <- plogis(beta[d$a] - beta[d$b])
d$win <- ifelse(runif(nrow(d)) < p, d$a, d$b)
plot_btl(btl(d, "a", "b", "win"))
}
